--- layout: template title: API - pyatv.exceptions permalink: /api//exceptions link_group: api ---

# Module `pyatv.exceptions`

Local exceptions used by library.

Expand source code

    """Local exceptions used by library."""

    class NoServiceError(Exception):
        """Thrown when connecting to a device with no usable service."""

    class UnsupportedProtocolError(Exception):
        """Thrown when an unsupported protocol was requested."""

    class ConnectionFailedError(Exception):
        """Thrown when connection fails, e.g. refused or timed out."""

    class PairingError(Exception):
        """Thrown when pairing fails."""

    class AuthenticationError(Exception):
        """Thrown when authentication fails."""

    class NotSupportedError(NotImplementedError):
        """Thrown when trying to perform an action that is not supported."""

    class InvalidDmapDataError(Exception):
        """Thrown when invalid DMAP data is parsed."""

    class UnknownMediaKindError(Exception):
        """Thrown when an unknown media kind is found."""

    class UnknownPlayStateError(Exception):
        """Thrown when an unknown play state is found."""

    class NoAsyncListenerError(Exception):
        """Thrown when starting AsyncUpdater with no listener."""

    class NoCredentialsError(Exception):
        """Thrown if credentials are missing."""

    class InvalidCredentialsError(Exception):
        """Thrown if credentials are invalid."""

    class DeviceIdMissingError(Exception):
        """Thrown when device id is missing."""

    class BackOffError(Exception):
        """Thrown when device mandates a backoff period."""

    class PlaybackError(Exception):
        """Thrown when media playback failed."""

    class CommandError(Exception):
        """Thrown when a command (e.g. play or pause) failed."""

## Classes

`class AuthenticationError (...)`

  Thrown when authentication fails.

  Expand source code

      class AuthenticationError(Exception):
          """Thrown when authentication fails."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class BackOffError (...)`

  Thrown when device mandates a backoff period.

  Expand source code

      class BackOffError(Exception):
          """Thrown when device mandates a backoff period."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class CommandError (...)`

  Thrown when a command (e.g. play or pause) failed.

  Expand source code

      class CommandError(Exception):
          """Thrown when a command (e.g. play or pause) failed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ConnectionFailedError (...)`

  Thrown when connection fails, e.g. refused or timed out.

  Expand source code

      class ConnectionFailedError(Exception):
          """Thrown when connection fails, e.g. refused or timed out."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class DeviceIdMissingError (...)`

  Thrown when device id is missing.

  Expand source code

      class DeviceIdMissingError(Exception):
          """Thrown when device id is missing."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidCredentialsError (...)`

  Thrown if credentials are invalid.

  Expand source code

      class InvalidCredentialsError(Exception):
          """Thrown if credentials are invalid."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidDmapDataError (...)`

  Thrown when invalid DMAP data is parsed.

  Expand source code

      class InvalidDmapDataError(Exception):
          """Thrown when invalid DMAP data is parsed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoAsyncListenerError (...)`

  Thrown when starting AsyncUpdater with no listener.

  Expand source code

      class NoAsyncListenerError(Exception):
          """Thrown when starting AsyncUpdater with no listener."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoCredentialsError (...)`

  Thrown if credentials are missing.

  Expand source code

      class NoCredentialsError(Exception):
          """Thrown if credentials are missing."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoServiceError (...)`

  Thrown when connecting to a device with no usable service.

  Expand source code

      class NoServiceError(Exception):
          """Thrown when connecting to a device with no usable service."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NotSupportedError (...)`

  Thrown when trying to perform an action that is not supported.

  Expand source code

      class NotSupportedError(NotImplementedError):
          """Thrown when trying to perform an action that is not supported."""

  ### Ancestors

  - builtins.NotImplementedError
  - builtins.RuntimeError
  - builtins.Exception
  - builtins.BaseException
`class PairingError (...)`

  Thrown when pairing fails.

  Expand source code

      class PairingError(Exception):
          """Thrown when pairing fails."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class PlaybackError (...)`

  Thrown when media playback failed.

  Expand source code

      class PlaybackError(Exception):
          """Thrown when media playback failed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnknownMediaKindError (...)`

  Thrown when an unknown media kind is found.

  Expand source code

      class UnknownMediaKindError(Exception):
          """Thrown when an unknown media kind is found."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnknownPlayStateError (...)`

  Thrown when an unknown play state is found.

  Expand source code

      class UnknownPlayStateError(Exception):
          """Thrown when an unknown play state is found."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnsupportedProtocolError (...)`

  Thrown when an unsupported protocol was requested.

  Expand source code

      class UnsupportedProtocolError(Exception):
          """Thrown when an unsupported protocol was requested."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException